Module mcp_api

Module mcp_api 

Enums

DeleteMcpError
struct for typed errors of method delete_mcp
GetMcpError
struct for typed errors of method get_mcp
PostMcpError
struct for typed errors of method post_mcp

Functions

delete_mcp
delete_mcp_request_builder
Implemented according to the Streamable HTTP Transport specification. Terminate an MCP session. The server implementation is stateless, so this is a no-op.
get_mcp
get_mcp_request_builder
Implemented according to the Streamable HTTP Transport specification.
post_mcp
post_mcp_request_builder
Implemented according to the Streamable HTTP Transport specification. Sends a JSON-RPC 2.0 message to the server. - Request: Provide an object with jsonrpc, id, method, and optional params. - Response: Returns a JSON-RPC response or acknowledgment. Notes: - Stateless: Sessions are not persisted across requests.