Enums
- Cancel
RunHttp Threads Thread IdRuns RunId Cancel Post Error - struct for typed errors of method
cancel_run_http_threads_thread_id_runs_run_id_cancel_post - Cancel
Runs Post Error - struct for typed errors of method
cancel_runs_post - Create
RunThreads Thread IdRuns Post Error - struct for typed errors of method
create_run_threads_thread_id_runs_post - Delete
RunThreads Thread IdRuns RunId Delete Error - struct for typed errors of method
delete_run_threads_thread_id_runs_run_id_delete - GetRun
Http Threads Thread IdRuns RunId GetError - struct for typed errors of method
get_run_http_threads_thread_id_runs_run_id_get - Join
RunHttp Threads Thread IdRuns RunId Join GetError - struct for typed errors of method
join_run_http_threads_thread_id_runs_run_id_join_get - List
Runs Http Threads Thread IdRuns GetError - struct for typed errors of method
list_runs_http_threads_thread_id_runs_get - Stream
RunHttp Threads Thread IdRuns RunId Join GetError - struct for typed errors of method
stream_run_http_threads_thread_id_runs_run_id_join_get - Stream
RunThreads Thread IdRuns Stream Post Error - struct for typed errors of method
stream_run_threads_thread_id_runs_stream_post - Wait
RunThreads Thread IdRuns Wait Post Error - struct for typed errors of method
wait_run_threads_thread_id_runs_wait_post
Functions
- cancel_
run_ http_ threads_ thread_ id_ runs_ run_ id_ cancel_ post - cancel_
run_ http_ threads_ thread_ id_ runs_ run_ id_ cancel_ post_ request_ builder - cancel_
runs_ post - cancel_
runs_ post_ request_ builder - Cancel one or more runs. Can cancel runs by thread ID and run IDs, or by status filter.
- create_
run_ threads_ thread_ id_ runs_ post - create_
run_ threads_ thread_ id_ runs_ post_ request_ builder - Create a run in existing thread, return the run ID immediately. Don’t wait for the final run output.
- delete_
run_ threads_ thread_ id_ runs_ run_ id_ delete - delete_
run_ threads_ thread_ id_ runs_ run_ id_ delete_ request_ builder - Delete a run by ID.
- get_
run_ http_ threads_ thread_ id_ runs_ run_ id_ get - get_
run_ http_ threads_ thread_ id_ runs_ run_ id_ get_ request_ builder - Get a run by ID.
- join_
run_ http_ threads_ thread_ id_ runs_ run_ id_ join_ get - join_
run_ http_ threads_ thread_ id_ runs_ run_ id_ join_ get_ request_ builder - Wait for a run to finish.
- list_
runs_ http_ threads_ thread_ id_ runs_ get - list_
runs_ http_ threads_ thread_ id_ runs_ get_ request_ builder - List runs for a thread.
- stream_
run_ http_ threads_ thread_ id_ runs_ run_ id_ join_ get - stream_
run_ http_ threads_ thread_ id_ runs_ run_ id_ join_ get_ request_ builder - Join a run stream. This endpoint streams output in real-time from a run similar to the /threads/THREAD_ID/runs/stream endpoint. If the run has been created with
stream_resumable=true, the stream can be resumed from the last seen event ID. - stream_
run_ threads_ thread_ id_ runs_ stream_ post - stream_
run_ threads_ thread_ id_ runs_ stream_ post_ request_ builder - Create a run in existing thread. Stream the output.
- wait_
run_ threads_ thread_ id_ runs_ wait_ post - wait_
run_ threads_ thread_ id_ runs_ wait_ post_ request_ builder - Create a run in existing thread. Wait for the final output and then return it.