Module threads_api

Module threads_api 

Enums

CopyThreadPostThreadsThreadIdCopyPostError
struct for typed errors of method copy_thread_post_threads_thread_id_copy_post
CountThreadsThreadsCountPostError
struct for typed errors of method count_threads_threads_count_post
CreateThreadThreadsPostError
struct for typed errors of method create_thread_threads_post
DeleteThreadThreadsThreadIdDeleteError
struct for typed errors of method delete_thread_threads_thread_id_delete
GetLatestThreadStateThreadsThreadIdStateGetError
struct for typed errors of method get_latest_thread_state_threads_thread_id_state_get
GetThreadHistoryPostThreadsThreadIdHistoryPostError
struct for typed errors of method get_thread_history_post_threads_thread_id_history_post
GetThreadHistoryThreadsThreadIdHistoryGetError
struct for typed errors of method get_thread_history_threads_thread_id_history_get
GetThreadStateAtCheckpointThreadsThreadIdStateCheckpointIdGetError
struct for typed errors of method get_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get
GetThreadThreadsThreadIdGetError
struct for typed errors of method get_thread_threads_thread_id_get
JoinThreadStreamThreadsThreadIdStreamGetError
struct for typed errors of method join_thread_stream_threads_thread_id_stream_get
PatchThreadThreadsThreadIdPatchError
struct for typed errors of method patch_thread_threads_thread_id_patch
PostThreadStateAtCheckpointThreadsThreadIdStateCheckpointIdGetError
struct for typed errors of method post_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get
SearchThreadsThreadsSearchPostError
struct for typed errors of method search_threads_threads_search_post
UpdateThreadStateThreadsThreadIdStatePostError
struct for typed errors of method update_thread_state_threads_thread_id_state_post

Functions

copy_thread_post_threads_thread_id_copy_post
copy_thread_post_threads_thread_id_copy_post_request_builder
Create a new thread with a copy of the state and checkpoints from an existing thread.
count_threads_threads_count_post
count_threads_threads_count_post_request_builder
Get the count of threads matching the specified criteria.
create_thread_threads_post
create_thread_threads_post_request_builder
Create a thread.
delete_thread_threads_thread_id_delete
delete_thread_threads_thread_id_delete_request_builder
Delete a thread by ID.
get_latest_thread_state_threads_thread_id_state_get
get_latest_thread_state_threads_thread_id_state_get_request_builder
Get state for a thread. The latest state of the thread (i.e. latest checkpoint) is returned.
get_thread_history_post_threads_thread_id_history_post
get_thread_history_post_threads_thread_id_history_post_request_builder
Get all past states for a thread.
get_thread_history_threads_thread_id_history_get
get_thread_history_threads_thread_id_history_get_request_builder
Get all past states for a thread.
get_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get
get_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get_request_builder
Get state for a thread at a specific checkpoint.
get_thread_threads_thread_id_get
get_thread_threads_thread_id_get_request_builder
Get a thread by ID.
join_thread_stream_threads_thread_id_stream_get
join_thread_stream_threads_thread_id_stream_get_request_builder
This endpoint streams output in real-time from a thread. The stream will include the output of each run executed sequentially on the thread and will remain open indefinitely. It is the responsibility of the calling client to close the connection.
patch_thread_threads_thread_id_patch
patch_thread_threads_thread_id_patch_request_builder
Update a thread.
post_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get
post_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get_request_builder
Get state for a thread at a specific checkpoint.
search_threads_threads_search_post
search_threads_threads_search_post_request_builder
Search for threads. This endpoint also functions as the endpoint to list all threads.
update_thread_state_threads_thread_id_state_post
update_thread_state_threads_thread_id_state_post_request_builder
Add state to a thread.