pub struct CheckpointConfig {
pub thread_id: Option<String>,
pub checkpoint_ns: Option<String>,
pub checkpoint_id: Option<String>,
pub checkpoint_map: Option<Value>,
}Expand description
CheckpointConfig : Checkpoint config.
Fields
thread_id: Option<String>Unique identifier for the thread associated with this checkpoint.
checkpoint_ns: Option<String>Namespace for the checkpoint, used for organization and retrieval.
checkpoint_id: Option<String>Optional unique identifier for the checkpoint itself.
checkpoint_map: Option<Value>Optional dictionary containing checkpoint-specific data.
Implementations
Sourceimpl CheckpointConfig
impl CheckpointConfig
Sourcepub fn new() -> CheckpointConfig
pub fn new() -> CheckpointConfig
Checkpoint config.