pub enum OnRunCompleted {
Delete,
Keep,
}Expand description
What to do with the thread after the run completes. ‘delete’ removes the thread after execution. ‘keep’ creates a new thread for each execution but does not clean them up.
Variants