Module cron_create_assistant_id

Module cron_create_assistant_id 

Structs

CronCreateAssistantId
CronCreateAssistantId : The assistant ID or graph name to run. If using graph name, will default to the assistant automatically created from that graph by the server.