pub enum Xray {
Boolean(bool),
Integer(i32),
}Expand description
Xray : Include graph representation of subgraphs. If an integer value is provided, only subgraphs with a depth less than or equal to the value will be included. Include graph representation of subgraphs. If an integer value is provided, only subgraphs with a depth less than or equal to the value will be included.
Variants