pub struct StoreListNamespacesRequest {
pub prefix: Option<Vec<String>>,
pub suffix: Option<Vec<String>>,
pub max_depth: Option<i32>,
pub limit: Option<i32>,
pub offset: Option<i32>,
}Fields
prefix: Option<Vec<String>>Optional list of strings representing the prefix to filter namespaces.
suffix: Option<Vec<String>>Optional list of strings representing the suffix to filter namespaces.
max_depth: Option<i32>Optional integer specifying the maximum depth of namespaces to return.
limit: Option<i32>Maximum number of namespaces to return (default is 100).
offset: Option<i32>Number of namespaces to skip before returning results (default is 0).
Implementations
Sourceimpl StoreListNamespacesRequest
impl StoreListNamespacesRequest
pub fn new() -> StoreListNamespacesRequest