pub struct AssistantPatch {
pub graph_id: Option<String>,
pub config: Option<Value>,
pub context: Option<Value>,
pub metadata: Option<Value>,
pub name: Option<String>,
pub description: Option<String>,
}Expand description
AssistantPatch : Payload for updating an assistant.
Fields
graph_id: Option<String>The ID of the graph the assistant should use. The graph ID is normally set in your langgraph.json configuration. If not provided, assistant will keep pointing to same graph.
config: Option<Value>Configuration to use for the graph. Useful when graph is configurable and you want to update the assistant’s configuration.
context: Option<Value>Static context added to the assistant.
metadata: Option<Value>Metadata to merge with existing assistant metadata.
name: Option<String>The new name for the assistant. If not provided, assistant will keep its current name.
description: Option<String>The new description for the assistant. If not provided, assistant will keep its current description.
Implementations
Sourceimpl AssistantPatch
impl AssistantPatch
Sourcepub fn new() -> AssistantPatch
pub fn new() -> AssistantPatch
Payload for updating an assistant.