pub struct CronCreateAssistantId {}Expand description
CronCreateAssistantId : The assistant ID or graph name to run. If using graph name, will default to the assistant automatically created from that graph by the server.
Implementations
Sourceimpl CronCreateAssistantId
impl CronCreateAssistantId
Sourcepub fn new() -> CronCreateAssistantId
pub fn new() -> CronCreateAssistantId
The assistant ID or graph name to run. If using graph name, will default to the assistant automatically created from that graph by the server.