pub struct Item {
pub namespace: Vec<String>,
pub key: String,
pub value: Value,
pub created_at: String,
pub updated_at: String,
}Expand description
Item : Represents a single document or data entry in the graph’s Store. Items are used to store cross-thread memories.
Fields
namespace: Vec<String>The namespace of the item. A namespace is analogous to a document’s directory.
key: StringThe unique identifier of the item within its namespace. In general, keys needn’t be globally unique.
value: ValueThe value stored in the item. This is the document itself.
created_at: StringThe timestamp when the item was created.
updated_at: StringThe timestamp when the item was last updated.
Implementations