pub struct RunCreateStateful {Show 20 fields
pub assistant_id: Box<RunCreateStatefulAssistantId>,
pub checkpoint: Option<CheckpointConfig>,
pub input: Option<Option<Box<Input1>>>,
pub command: Option<Option<Box<Command>>>,
pub metadata: Option<Value>,
pub config: Option<Box<Config3>>,
pub context: Option<Value>,
pub webhook: Option<String>,
pub interrupt_before: Option<Box<InterruptBefore1>>,
pub interrupt_after: Option<Box<InterruptAfter1>>,
pub stream_mode: Option<Box<StreamMode>>,
pub stream_subgraphs: Option<bool>,
pub stream_resumable: Option<bool>,
pub on_disconnect: Option<OnDisconnect>,
pub feedback_keys: Option<Vec<String>>,
pub multitask_strategy: Option<MultitaskStrategy>,
pub if_not_exists: Option<IfNotExists>,
pub after_seconds: Option<f64>,
pub checkpoint_during: Option<bool>,
pub durability: Option<Durability>,
}Expand description
RunCreateStateful : Payload for creating a run.
Fields
assistant_id: Box<RunCreateStatefulAssistantId>checkpoint: Option<CheckpointConfig>The checkpoint to resume from.
input: Option<Option<Box<Input1>>>command: Option<Option<Box<Command>>>metadata: Option<Value>Metadata to assign to the run.
config: Option<Box<Config3>>context: Option<Value>Static context added to the assistant.
webhook: Option<String>Webhook to call after LangGraph API call is done.
interrupt_before: Option<Box<InterruptBefore1>>interrupt_after: Option<Box<InterruptAfter1>>stream_mode: Option<Box<StreamMode>>stream_subgraphs: Option<bool>Whether to stream output from subgraphs.
stream_resumable: Option<bool>Whether to persist the stream chunks in order to resume the stream later.
on_disconnect: Option<OnDisconnect>The disconnect mode to use. Must be one of ‘cancel’ or ‘continue’.
feedback_keys: Option<Vec<String>>Feedback keys to assign to run.
multitask_strategy: Option<MultitaskStrategy>Multitask strategy to use. Must be one of ‘reject’, ‘interrupt’, ‘rollback’, or ‘enqueue’.
if_not_exists: Option<IfNotExists>How to handle missing thread. Must be either ‘reject’ (raise error if missing), or ‘create’ (create new thread).
after_seconds: Option<f64>The number of seconds to wait before starting the run. Use to schedule future runs.
checkpoint_during: Option<bool>Whether to checkpoint during the run.
durability: Option<Durability>Durability level for the run. Must be one of ‘sync’, ‘async’, or ‘exit’.
Implementations
Sourceimpl RunCreateStateful
impl RunCreateStateful
Sourcepub fn new(assistant_id: RunCreateStatefulAssistantId) -> RunCreateStateful
pub fn new(assistant_id: RunCreateStatefulAssistantId) -> RunCreateStateful
Payload for creating a run.