pub struct RunCreateStatefulAssistantId {}Expand description
RunCreateStatefulAssistantId : The assistant ID or graph name to run. If using graph name, will default to first assistant created from that graph.
Implementations
Sourceimpl RunCreateStatefulAssistantId
impl RunCreateStatefulAssistantId
Sourcepub fn new() -> RunCreateStatefulAssistantId
pub fn new() -> RunCreateStatefulAssistantId
The assistant ID or graph name to run. If using graph name, will default to first assistant created from that graph.