pub struct RunCreateStateless {Show 16 fields
pub assistant_id: Box<RunCreateStatefulAssistantId>,
pub input: Option<Option<Box<Input1>>>,
pub command: Option<Option<Box<Command>>>,
pub metadata: Option<Value>,
pub config: Option<Box<Config3>>,
pub context: Option<Value>,
pub webhook: Option<String>,
pub stream_mode: Option<Box<StreamMode>>,
pub feedback_keys: Option<Vec<String>>,
pub stream_subgraphs: Option<bool>,
pub stream_resumable: Option<bool>,
pub on_completion: Option<OnCompletion>,
pub on_disconnect: Option<OnDisconnect>,
pub after_seconds: Option<f64>,
pub checkpoint_during: Option<bool>,
pub durability: Option<Durability>,
}Expand description
RunCreateStateless : Payload for creating a run.
Fields
assistant_id: Box<RunCreateStatefulAssistantId>input: Option<Option<Box<Input1>>>command: Option<Option<Box<Command>>>metadata: Option<Value>Metadata to assign to the run.
config: Option<Box<Config3>>context: Option<Value>Static context added to the assistant.
webhook: Option<String>Webhook to call after LangGraph API call is done.
stream_mode: Option<Box<StreamMode>>feedback_keys: Option<Vec<String>>Feedback keys to assign to run.
stream_subgraphs: Option<bool>Whether to stream output from subgraphs.
stream_resumable: Option<bool>Whether to persist the stream chunks in order to resume the stream later.
on_completion: Option<OnCompletion>Whether to delete or keep the thread created for a stateless run. Must be one of ‘delete’ or ‘keep’.
on_disconnect: Option<OnDisconnect>The disconnect mode to use. Must be one of ‘cancel’ or ‘continue’.
after_seconds: Option<f64>The number of seconds to wait before starting the run. Use to schedule future runs.
checkpoint_during: Option<bool>Whether to checkpoint during the run.
durability: Option<Durability>Durability level for the run. Must be one of ‘sync’, ‘async’, or ‘exit’.
Implementations
Sourceimpl RunCreateStateless
impl RunCreateStateless
Sourcepub fn new(assistant_id: RunCreateStatefulAssistantId) -> RunCreateStateless
pub fn new(assistant_id: RunCreateStatefulAssistantId) -> RunCreateStateless
Payload for creating a run.