Enums
- Copy
Thread Post Threads Thread IdCopy Post Error - struct for typed errors of method
copy_thread_post_threads_thread_id_copy_post - Count
Threads Threads Count Post Error - struct for typed errors of method
count_threads_threads_count_post - Create
Thread Threads Post Error - struct for typed errors of method
create_thread_threads_post - Delete
Thread Threads Thread IdDelete Error - struct for typed errors of method
delete_thread_threads_thread_id_delete - GetLatest
Thread State Threads Thread IdState GetError - struct for typed errors of method
get_latest_thread_state_threads_thread_id_state_get - GetThread
History Post Threads Thread IdHistory Post Error - struct for typed errors of method
get_thread_history_post_threads_thread_id_history_post - GetThread
History Threads Thread IdHistory GetError - struct for typed errors of method
get_thread_history_threads_thread_id_history_get - GetThread
State AtCheckpoint Threads Thread IdState Checkpoint IdGet Error - struct for typed errors of method
get_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get - GetThread
Threads Thread IdGet Error - struct for typed errors of method
get_thread_threads_thread_id_get - Join
Thread Stream Threads Thread IdStream GetError - struct for typed errors of method
join_thread_stream_threads_thread_id_stream_get - Patch
Thread Threads Thread IdPatch Error - struct for typed errors of method
patch_thread_threads_thread_id_patch - Post
Thread State AtCheckpoint Threads Thread IdState Checkpoint IdGet Error - struct for typed errors of method
post_thread_state_at_checkpoint_threads_thread_id_state_checkpoint_id_get - Search
Threads Threads Search Post Error - struct for typed errors of method
search_threads_threads_search_post - Update
Thread State Threads Thread IdState Post Error - struct for typed errors of method
update_thread_state_threads_thread_id_state_post
Functions
- copy_
thread_ post_ threads_ thread_ id_ copy_ post - copy_
thread_ post_ threads_ thread_ id_ copy_ post_ request_ builder - Create a new thread with a copy of the state and checkpoints from an existing thread.
- count_
threads_ threads_ count_ post - count_
threads_ threads_ count_ post_ request_ builder - Get the count of threads matching the specified criteria.
- create_
thread_ threads_ post - create_
thread_ threads_ post_ request_ builder - Create a thread.
- delete_
thread_ threads_ thread_ id_ delete - delete_
thread_ threads_ thread_ id_ delete_ request_ builder - Delete a thread by ID.
- get_
latest_ thread_ state_ threads_ thread_ id_ state_ get - get_
latest_ thread_ state_ threads_ thread_ id_ state_ get_ request_ builder - Get state for a thread. The latest state of the thread (i.e. latest checkpoint) is returned.
- get_
thread_ history_ post_ threads_ thread_ id_ history_ post - get_
thread_ history_ post_ threads_ thread_ id_ history_ post_ request_ builder - Get all past states for a thread.
- get_
thread_ history_ threads_ thread_ id_ history_ get - get_
thread_ history_ threads_ thread_ id_ history_ get_ request_ builder - Get all past states for a thread.
- get_
thread_ state_ at_ checkpoint_ threads_ thread_ id_ state_ checkpoint_ id_ get - get_
thread_ state_ at_ checkpoint_ threads_ thread_ id_ state_ checkpoint_ id_ get_ request_ builder - Get state for a thread at a specific checkpoint.
- get_
thread_ threads_ thread_ id_ get - get_
thread_ threads_ thread_ id_ get_ request_ builder - Get a thread by ID.
- join_
thread_ stream_ threads_ thread_ id_ stream_ get - join_
thread_ stream_ threads_ thread_ id_ stream_ get_ request_ builder - This endpoint streams output in real-time from a thread. The stream will include the output of each run executed sequentially on the thread and will remain open indefinitely. It is the responsibility of the calling client to close the connection.
- patch_
thread_ threads_ thread_ id_ patch - patch_
thread_ threads_ thread_ id_ patch_ request_ builder - Update a thread.
- post_
thread_ state_ at_ checkpoint_ threads_ thread_ id_ state_ checkpoint_ id_ get - post_
thread_ state_ at_ checkpoint_ threads_ thread_ id_ state_ checkpoint_ id_ get_ request_ builder - Get state for a thread at a specific checkpoint.
- search_
threads_ threads_ search_ post - search_
threads_ threads_ search_ post_ request_ builder - Search for threads. This endpoint also functions as the endpoint to list all threads.
- update_
thread_ state_ threads_ thread_ id_ state_ post - update_
thread_ state_ threads_ thread_ id_ state_ post_ request_ builder - Add state to a thread.