Structs
- Cron
Create - CronCreate : Payload for creating a stateless cron job (creates a new thread for each execution).
Enums
- OnRun
Completed - What to do with the thread after the run completes. ‘delete’ removes the thread after execution. ‘keep’ creates a new thread for each execution but does not clean them up.