pub struct CronCreate {
pub schedule: String,
pub end_time: Option<String>,
pub assistant_id: Box<CronCreateAssistantId>,
pub input: Option<Box<Input>>,
pub metadata: Option<Value>,
pub config: Option<Box<Config2>>,
pub context: Option<Value>,
pub webhook: Option<String>,
pub interrupt_before: Option<Box<InterruptBefore>>,
pub interrupt_after: Option<Box<InterruptAfter>>,
pub on_run_completed: Option<OnRunCompleted>,
}Expand description
CronCreate : Payload for creating a stateless cron job (creates a new thread for each execution).
Fields
schedule: StringThe cron schedule to execute this job on.
end_time: Option<String>The end date to stop running the cron.
assistant_id: Box<CronCreateAssistantId>input: Option<Box<Input>>metadata: Option<Value>Metadata to assign to the cron job runs.
config: Option<Box<Config2>>context: Option<Value>Static context added to the assistant.
webhook: Option<String>Webhook to call after LangGraph API call is done.
interrupt_before: Option<Box<InterruptBefore>>interrupt_after: Option<Box<InterruptAfter>>on_run_completed: Option<OnRunCompleted>What to do with the thread after the run completes. ‘delete’ removes the thread after execution. ‘keep’ creates a new thread for each execution but does not clean them up.
Implementations
Sourceimpl CronCreate
impl CronCreate
Sourcepub fn new(schedule: String, assistant_id: CronCreateAssistantId) -> CronCreate
pub fn new(schedule: String, assistant_id: CronCreateAssistantId) -> CronCreate
Payload for creating a stateless cron job (creates a new thread for each execution).